@@ -1,7 +1,9 @@
 package App::ShellCompleter::YoutubeDl;
 
-our $DATE = '2019-07-18'; # DATE
-our $VERSION = '0.121'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-09-09'; # DATE
+our $DIST = 'App-ShellCompleter-YoutubeDl'; # DIST
+our $VERSION = '0.122'; # VERSION
 
 1;
 # ABSTRACT: Shell completion for youtube-dl
@@ -18,7 +20,7 @@ App::ShellCompleter::YoutubeDl - Shell completion for youtube-dl
 
 =head1 VERSION
 
-This document describes version 0.121 of App::ShellCompleter::YoutubeDl (from Perl distribution App-ShellCompleter-YoutubeDl), released on 2019-07-18.
+This document describes version 0.122 of App::ShellCompleter::YoutubeDl (from Perl distribution App-ShellCompleter-YoutubeDl), released on 2020-09-09.
 
 =head1 SYNOPSIS
 
@@ -50,7 +52,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2017, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2017, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
